@@ -6,9 +6,9 @@
 #ifndef PRACTICE_MAINWINDOW_H
 #define PRACTICE_MAINWINDOW_H
 
+#include "sessionmanagerbase.h"
 #include <KXmlGuiWindow>
 #include <QKeyEvent>
-#include "sessionmanagerbase.h"
 
 class ParleyMainWindow;
 class KToggleFullScreenAction;
@@ -24,8 +24,8 @@ class PracticeMainWindow : public KXmlGuiWindow
 {
     Q_OBJECT
 public:
-    explicit PracticeMainWindow(SessionManagerBase* sessionManager, ParleyMainWindow* mainWindow = 0);
-    ~PracticeMainWindow();
+    explicit PracticeMainWindow(SessionManagerBase *sessionManager, ParleyMainWindow *mainWindow = nullptr);
+    ~PracticeMainWindow() override;
 
     void startPractice();
 
@@ -38,18 +38,18 @@ Q_SIGNALS:
     void stopPractice();
 
 protected:
-    void resizeEvent(QResizeEvent *e) Q_DECL_OVERRIDE;
-    bool event(QEvent *event) Q_DECL_OVERRIDE;
+    void resizeEvent(QResizeEvent *e) override;
+    bool event(QEvent *event) override;
 
 private:
     void initActions();
 
-    GuiFrontend* m_guiFrontend;
-    PracticeStateMachine* m_stateMachine;
-    ParleyMainWindow* m_mainWindow;
-    QWidget* m_floatingToolBar;
-    KToggleFullScreenAction* m_fullScreenAction;
-    QPropertyAnimation* m_animation;
+    GuiFrontend *m_guiFrontend{nullptr};
+    PracticeStateMachine *m_stateMachine{nullptr};
+    ParleyMainWindow *m_mainWindow{nullptr};
+    QWidget *m_floatingToolBar{nullptr};
+    KToggleFullScreenAction *m_fullScreenAction{nullptr};
+    QPropertyAnimation *m_animation{nullptr};
 };
 }
 
